<template>
    <div>
        <div
            class="modal fade"
            tabindex="-1"
            :class="{ show: isVisible }"
            :style="{ display: isVisible ? 'block' : 'none' }"
            role="dialog"
        >
            <div class="modal-dialog modal-dialog-centered" role="document">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title">{{ title }}</h5>
                        <button
                            type="button"
                            class="btn-close"
                            aria-label="Close"
                            @click="closeModal"
                        ></button>
                    </div>
                    <div class="modal-body">
                        <p class="">{{ message }}</p>
                    </div>
                    <div class="modal-footer">
                        <BaseButton
                            class="btn-outline-primary"
                            @click="closeModal"
                        >
                            Close
                        </BaseButton>
                        <BaseButton
                            class="btn-danger"
                            @click="confirmAction"
                        >
                            Confirm
                        </BaseButton>
                    </div>
                </div>
            </div>
        </div>

        <!-- Backdrop -->
        <div
            class="modal-backdrop fade"
            :class="{ show: isVisible }"
            v-if="isVisible"
        ></div>
    </div>
</template>

<script setup>
import {defineEmits, defineProps} from "vue";
import BaseButton from "@/Components/Button/BaseButton.vue";

defineProps({
    title: {
        type: String,
        default: "Confirmation",
    },
    message: {
        type: String,
        default: "Are you sure you want to proceed?",
    },
    isVisible: {
        type: Boolean,
        required: true,
    },
});

const emit = defineEmits(["close", "confirmed"]);

const closeModal = () => {
    emit("close");
};

const confirmAction = () => {
    emit("confirmed");
    closeModal();
};
</script>

<style scoped>
.modal.fade.show {
    display: block;
    background-color: rgba(0, 0, 0, 0.5);
}
</style>
